==> orgmaker-3-3.0.5.tar.gz: orgmaker-3-3.0.5/README.md <==
# &#x1F3BC; *Organya 3*

**Fork of A music sequencer for retro video games**  

This does not use a MIDI device.  
This original library was created by [Studio Pixel](http://studiopixel.sakura.ne.jp/) in 1999, and was used in [Cave Story](https://www.cavestory.org/).

<img src='/previmg.png' width=60% height=60%>

## &#x1F352; Introduction

For the '[STARGAZER](http://www5b.biglobe.ne.jp/~kiss-me/aji/star/)' development, I inherited this library from [Studio Pixel](http://studiopixel.sakura.ne.jp/) in 2003.  
However, due to a change in my private life, it became inactive for a long time. On the other hand, the world expansion of Cave Story has increased the number of people requesting Organya.

-----

Mastermind.

In 1999, Studio Pixel produced the song composition software Organya for "Cave Story".

    Basically an internal development tool, and not very general, occasionally people who say "I like the shabby sound for some reason" and even "I want to compose with that sound" call this tool perfect.

With the world knowing the development of "Cave Story", which increased the demand of Organya, and the same for the opinion for how to manage the source code, I have made the repository public.

首謀です。

1999年に[開発室Pixel](http://studiopixel.sakura.ne.jp/)にて制作、後に「洞窟物語」にて使用されたオルガーニャ音源の作曲ソフトです。  
>基本的には開発室内で使うツールなので、あまり一般的とは言えませんが、まれに｢なぜかショボイ音が好き｣と言う人がいて、更に｢その音で作曲したい｣というのならこのツールはウッテツケです☆  

ご存知「洞窟物語」の世界展開により、その音源であるオルガーニャへの要望が増えた一方で、長期にわたり手つかずとなってしまったソースコードをいい加減何とかしろという声も同様に世界からチラホラと舞い込んできたのでリポジトリを公開することとしました。

-----


## &#x1F352; Features
* 8 Melody Tracks + 8 Drum Trucks (Each track can play one sound)  
* Melody track can be selected from 100 waveforms.  
* Drum track can be selected from 42 sounds.  
* Melody track can adjust the frequency to make the chorus effect.  
* You can loop music indefinitely in a measure.  
* Export to standard MIDI file (GM format).  


# &#x1F34E; Requirements
## &#x1F352; for Utilization
* Windows 2000, XP, Vista, 7, 8, 8.1, 10, maybe more...  
* [DirectX](https://www.google.com/search?q=DirectX+download) 8, 9, 10, 11, maybe more...  
* [Microsoft Visual C++ 6.0 Runtime Components](https://www.google.com/search?q=visual+c%2B%2B+6+runtime+library+download)  

## &#x1F352; for Development
* Microsoft Visual Studio 2019


# &#x1F34E; Usage

If you only use Organya, check out the [releases](https://github.com/Strultz/organya-3/releases).

# &#x1F34E; Contributing
This project was developed in Japanese. The help file is also written in Japanese as well.
I translated it to English anyway

# &#x1F34E; Author
## &#x1F352; Organya 3

[Strultz](http://www.strultz.com/)
## &#x1F352; Twei

[Rxo Inverse](http://www5b.biglobe.ne.jp/~kiss-me/aji/) (首謀)  

## &#x1F352; Original
[Studio Pixel](http://studiopixel.sakura.ne.jp/) (開発室Pixel)

# &#x1F34E; License
BSD

==> orgmaker-3-3.0.6.tar.gz: orgmaker-3-3.0.6/README.md <==
# &#x1F3BC; *Organya 3*

**Fork of A music sequencer for retro video games**  

This does not use a MIDI device.  
This original library was created by [Studio Pixel](http://studiopixel.sakura.ne.jp/) in 1999, and was used in [Cave Story](https://www.cavestory.org/).

<img src='/previmg.png' width=60% height=60%>

## &#x1F352; Introduction

For the '[STARGAZER](http://www5b.biglobe.ne.jp/~kiss-me/aji/star/)' development, I inherited this library from [Studio Pixel](http://studiopixel.sakura.ne.jp/) in 2003.  
However, due to a change in my private life, it became inactive for a long time. On the other hand, the world expansion of Cave Story has increased the number of people requesting Organya.

-----

Mastermind.

In 1999, Studio Pixel produced the song composition software Organya for "Cave Story".

>Basically an internal development tool, and not very general, occasionally people who say "I like the shabby sound for some reason" and even "I want to compose with that sound" call this tool perfect.

With the world knowing the development of "Cave Story", which increased the demand of Organya, and the same for the opinion for how to manage the source code, I have made the repository public.

-----


## &#x1F352; Features
* 8 Melody Tracks + 8 Drum Trucks (Each track can play one sound)  
* Melody track can be selected from 100 waveforms.  
* Drum track can be selected from 42 sounds.  
* Melody track can adjust the frequency to make the chorus effect.  
* You can loop music indefinitely in a measure.  
* Export to standard MIDI file (GM format).  


# &#x1F34E; Requirements
## &#x1F352; for Utilization
* Windows 2000, XP, Vista, 7, 8, 8.1, 10, maybe more...  
* [DirectX](https://www.google.com/search?q=DirectX+download) 8, 9, 10, 11, maybe more...  
* [Microsoft Visual C++ 6.0 Runtime Components](https://www.google.com/search?q=visual+c%2B%2B+6+runtime+library+download)  

## &#x1F352; for Development
* Microsoft Visual Studio 2019


# &#x1F34E; Usage

If you only use Organya, check out the [releases](https://github.com/Strultz/organya-3/releases).

# &#x1F34E; Contributing
This project was developed in Japanese. The help file is also written in Japanese as well.
I translated it to English anyway

# &#x1F34E; Author
## &#x1F352; Organya 3

[Strultz](http://www.strultz.com/)
## &#x1F352; Twei

[Rxo Inverse](http://www5b.biglobe.ne.jp/~kiss-me/aji/) (首謀)  

## &#x1F352; Original
[Studio Pixel](http://studiopixel.sakura.ne.jp/) (開発室Pixel)

# &#x1F34E; License
BSD
